@@ -97,11 +97,16 @@ class RestClientMetaClass(type):
         else:
             required_args = rest_resource.required_args + \
                 [rest_resource.object_arg]
+        if extra_view_desc["method"] in ["put", "post"]:
+            requires_data=True
+        else:
+            requires_data = False
         func = cls._generate_resource_func(
             func_name,
             resource_field_name,
             required_args,
-            extra_view_name=extra_view_desc["path"])
+            extra_view_name=extra_view_desc["path"],
+            requires_data=requires_data)
         setattr(cls, func_name, func)
 
     def _generate_resource_func(cls, func_name, resource_field_name,
@@ -144,12 +149,17 @@ class Client(object):
     This class should be initialized either with a username, password and
     account name combination, or with an API key. Once you have initialized
     the client you will need to call :meth:`authenticate()` before you can
-    begin making API calls.
+    begin making API calls. ::
 
         >>>import kazoo
         >>>client = kazoo.Client(api_key="sdfasdfas")
         >>>client.authenticate()
 
+    You can also initialize with a username and password combination: ::
+
+        >>>client = kazoo.Client(username="myusername", password="mypassword", account_name="my_account_name")
+        >>>client.authenticate()
+
     API calls which require data take it in the form of a required argument
     called 'data' which is the last argument to the method. For example ::
 
@@ -185,7 +195,7 @@ class Client(object):
 
     For each resource exposed by the kazoo api there are corresponding methods
     on the client. For example, for the 'callflows' resource the
-    correspondence is as follows.
+    correspondence is as follows. ::
 
         GET /accounts/{account_id}/callflows -> client.get_callflows(acct_id)
         GET /accounts/{account_id}/callflows/{callflow_id} -> client.get_callflow(acct_id, callflow_id)
@@ -196,8 +206,9 @@ class Client(object):
     Some resources do not have all methods available, in which case they are
     not present on the client.
 
-    There are also some resources which don't quite fit this paradigm, they are:
+    There are also some resources which don't quite fit this paradigm, they are: ::
 
+        GET /accounts/{account_id}/media -> client.get_all_media(acct_id)
         GET /accounts/{account_id}/children -> client.get_account_children(acct_id)
         GET /accounts/{account_id}/descendants -> client.get_account_descendants(acct_id)
         GET /accounts/{account_id}/devices/status -> client.get_all_devices_status(acct_id)
@@ -252,7 +263,12 @@ class Client(object):
                                    "/accounts/{account_id}/menus/{menu_id}")
     _phone_number_resource = RestResource(
         "phone_number",
-        "/accounts/{account_id}/phone_numbers/{phone_number_id}")
+        "/accounts/{account_id}/phone_numbers/{phone_number}",
+        methods=["list", "update", "delete"],
+        extra_views=[
+            {"name":"activate_phone_number",
+             "path": "activate",
+             "scope": "object"}])
     _queues_resource = RestResource("queue",
                                     "/accounts/{account_id}/queues/{queue_id}")
     _server_resource = RestResource(
@@ -263,12 +279,12 @@ class Client(object):
             {"name": "get_deployment",
              "path": "deployment",
              "scope": "object"},
+            {"name": "create_deployment",
+             "path": "deployment",
+             "scope": "object",
+             "method": "put"},
             {"name": "get_server_log", "path": "log"}
         ])
-    _create_server_deployment_resource = RestResource(
-        "server_deployment",
-        "/accounts/{account_id}/servers/{server_id}/deployment/{ignored}",
-        methods=["create"])
     _temporal_rules_resource = RestResource(
         "temporal_rule",
         "/accounts/{account_id}/temporal_rules/{rule_id}")
@@ -278,7 +294,8 @@ class Client(object):
         extra_views=[{"name": "get_hotdesk", "path": "hotdesk"}])
     _vmbox_resource = RestResource(
         "voicemail_box",
-        "/accounts/{account_id}/vmboxes/{vmbox_id}")
+        "/accounts/{account_id}/vmboxes/{vmbox_id}",
+        plural_name="voicemail_boxes")
 
     def __init__(self, api_key=None, password=None, account_name=None,
                  username=None):
@@ -316,3 +333,17 @@ class Client(object):
         if request.auth_required:
             kwargs["token"] = self.auth_token
         return request.execute(self.BASE_URL, **kwargs)
+
+    def search_phone_numbers(self, prefix, quantity=10):
+        request = KazooRequest("/phone_numbers", get_params={
+            "prefix": prefix,
+            "quantity": quantity
+        })
+        return self._execute_request(request)
+
+    def create_phone_number(self, acct_id, phone_number):
+        request = KazooRequest("/accounts/{account_id}/phone_numbers/{phone_number}",
+                               method="put")
+        return self._execute_request(request,
+                                     account_id=acct_id, phone_number=phone_number)
+
